#!/usr/bin/python
# -*- coding: utf-8 -*-

# Cagou: desktop/mobile frontend for Salut à Toi XMPP client
# Copyright (C) 2016 Jérôme Poisson (goffi@goffi.org)

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from sat.core import log as logging
log = logging.getLogger(__name__)
from sat.core.i18n import _
from sat_frontends.quick_frontend.quick_contact_list import QuickContactList
from kivy.uix.boxlayout import BoxLayout
from kivy.uix.listview import ListView
from kivy.adapters.listadapter import ListAdapter
from kivy import properties
from cagou.core import cagou_widget
from cagou.core import image
from cagou import G


PLUGIN_INFO = {
    "name": _(u"contacts"),
    "main": "ContactList",
    "description": _(u"list of contacts"),
}


class Avatar(image.Image):
    pass


class ContactItem(BoxLayout):
    data = properties.DictProperty()
    jid = properties.StringProperty('')

    def __init__(self, **kwargs):
        BoxLayout.__init__(self, **kwargs)


class ContactList(QuickContactList, cagou_widget.CagouWidget):

    def __init__(self, host, target, profiles):
        QuickContactList.__init__(self, G.host, profiles)
        cagou_widget.CagouWidget.__init__(self)
        self.adapter = ListAdapter(data={},
                                   cls=ContactItem,
                                   args_converter=self.contactDataConverter,
                                   selection_mode='multiple',
                                   allow_empty_selection=True,
                                  )
        self.add_widget(ListView(adapter=self.adapter))
        self.postInit()
        self.update()

    def contactDataConverter(self, idx, bare_jid):
        return {"jid": bare_jid, "data": self._items_cache[bare_jid]}

    def update(self, entities=None, type_=None, profile=None):
        log.info("update: %s %s %s" % (entities, type_, profile))
        # FIXME: for now we update on each event
        # if entities is None and type_ is None:
        self._items_cache = self.items
        self.adapter.data = self.items_sorted

